@@ -6,8 +6,9 @@ network by setting the values of the Network data class.
 
 """
 import dataclasses
+import enum
 import os
-from typing import Dict, Optional
+from typing import Dict, List, Optional
 
 
 @dataclasses.dataclass
@@ -159,7 +160,7 @@ class Network:
         return self.env
 
     @classmethod
-    def devnet(cls, chain_num: int = 2) -> "Network":
+    def devnet(cls, chain_num: int = 3) -> "Network":
         """
         Devnet is a network open to invited validators.
 
@@ -178,3 +179,38 @@ class Network:
             fee_denom='unibi',
             env='devnet',
         )
+
+    @classmethod
+    def from_chain_id(cls, chain_id: str) -> "Network":
+        """
+        Soon!
+        """
+
+        chain_id_elements: List[str] = chain_id.split("-")
+        if len(chain_id_elements) != 3:
+            raise ValueError(
+                f"invalid chain_id format: {chain_id}. Expected one like nibiru-testnet-2"
+            )
+
+        prefix, chain_type, chain_number = chain_id_elements
+        chain_number = int(chain_number)
+
+        if chain_type == NetworkType.DEVNET.value:
+            return Network.devnet(chain_number)
+        elif chain_type == NetworkType.TESTNET.value:
+            return Network.testnet(chain_number)
+        elif chain_type == NetworkType.LOCALNET.value:
+            return Network.localnet()
+        else:
+            network_types: List[str] = [member.value for member in NetworkType]
+            raise ValueError(
+                f"invalid chain type: {chain_type}. Available options: {network_types}"
+            )
+
+
+class NetworkType(enum.Enum):
+    """Enum class for the available network types. E.g. 'testnet' and 'devnet'."""
+
+    DEVNET = "devnet"
+    TESTNET = "testnet"
+    LOCALNET = "localnet"
